@@ -1,7 +1,4 @@
-import dash
-from dash import dcc
 from dash import html
-import dash_bootstrap_components as dbc
 
 import quickboard.styles as styles
 
